module.exports = {
    env: {
        es6: true,
        browser: true,
    },
    settings: {
        react: {
            version: "detect",
        },
    },
    extends: [
        "eslint:recommended",
        "plugin:react/recommended",
		"plugin:react/jsx-runtime",
        "plugin:react-hooks/recommended",
        "plugin:@typescript-eslint/recommended",
        "plugin:@typescript-eslint/recommended-requiring-type-checking",
        "plugin:import/errors",
        "plugin:import/warnings",
        "plugin:import/typescript",
    ],
    parser: "@typescript-eslint/parser",
    parserOptions: {
        project: "tsconfig.json",
        sourceType: "module",
        ecmaFeatures: {
          jsx: true,
        },
    },
    plugins: [
        "@typescript-eslint",
        "prefer-arrow",
        "react",
        "react-hooks",
    ],
    rules: {
		"@typescript-eslint/array-type": "error",
		"@typescript-eslint/ban-types": "off",
		"@typescript-eslint/consistent-type-assertions": "error",
		"@typescript-eslint/consistent-type-definitions": ["error", "interface"],
		"@typescript-eslint/consistent-type-imports": "error",
		"@typescript-eslint/dot-notation": "error",
		"@typescript-eslint/explicit-member-accessibility": "error",
		"@typescript-eslint/explicit-module-boundary-types": "off",
		"@typescript-eslint/member-delimiter-style": "error",
		"@typescript-eslint/no-duplicate-enum-values": "warn",
		"@typescript-eslint/no-explicit-any": "off",
		"@typescript-eslint/no-floating-promises": "error",
		"@typescript-eslint/no-inferrable-types": "off",
		"@typescript-eslint/no-namespace": "off",
		"@typescript-eslint/no-non-null-assertion": "off",
		"@typescript-eslint/no-shadow": ["error"],
		"@typescript-eslint/no-unsafe-assignment": "off",
		"@typescript-eslint/no-unsafe-call": "off",
		"@typescript-eslint/no-unsafe-member-access": "off",
		"@typescript-eslint/no-unsafe-return": "off",
		"@typescript-eslint/no-unused-expressions": "error",
		"no-unused-vars": "off",
        "@typescript-eslint/no-unused-vars": ["error", {
            vars: "all",
            args: "none",
            ignoreRestSiblings: false,
        }],
        "@typescript-eslint/prefer-for-of": "error",
        "@typescript-eslint/prefer-function-type": "error",
        "@typescript-eslint/prefer-regexp-exec": "off",
        "@typescript-eslint/quotes": ["error", "double", {
            avoidEscape: true,
            allowTemplateLiterals: true,
        }],
        "@typescript-eslint/require-await": "off",
        "@typescript-eslint/restrict-template-expressions": "off",
        "@typescript-eslint/semi": ["error", "always", {
            omitLastInOneLineBlock: false,
        }],
        "@typescript-eslint/type-annotation-spacing": "error",
        "@typescript-eslint/unified-signatures": "error",
        "arrow-body-style": "error",
        "arrow-parens": ["error", "as-needed"],
        "brace-style": "error",
        "comma-dangle": ["error", "always-multiline"],
        "curly": "error",
        "eol-last": "error",
        "eqeqeq": "error",
        "guard-for-in": "error",
		"import/no-unresolved": ["error", { ignore: ["\\.svg\\?react$"] }],
        indent: ["error", "tab", {
			"SwitchCase": 1,
		}],
        "max-len": ["error", {
            code: 140,
        }],
        "new-parens": "error",
        "no-caller": "error",
        "no-console": "error",
        "no-constant-condition": "off",
        "no-eval": "error",
        "no-multiple-empty-lines": "error",
        "no-new-wrappers": "error",
        "no-throw-literal": "error",
        "no-trailing-spaces": "error",
        "no-undef-init": "error",
        "no-useless-rename": "error",
        "object-curly-spacing": ["error", "always"],
        "object-shorthand": "error",
        "one-var": ["error", "never"],
        "prefer-arrow-callback": "error",
        "prefer-const": ["error", {
            destructuring: "all",
        }],
        "quote-props": ["error", "as-needed"],
        "radix": "error",
        "react-hooks/exhaustive-deps": "error",
        "space-before-function-paren": ["error", {
            anonymous: "never",
            asyncArrow: "always",
            named: "never",
        }],
        "spaced-comment": ["error", "always", {
            markers: ["/"],
            block: {
                balanced: true,
            },
        }],
    },
};
