# Self-Service Frontend

The frontend of the new faculty-wide User Self-Service, FSI Self-Service (FSI = Fachschaften der Fakultät für Informatik)!

The FSI Self-Service allows you to view and, partially, change some basic information about your FSI account, such as your name, major, and assigned groups.
Notably, it also allows you to link your [Discord](https://fsi.rub.de/links/)-Account to your FSI account, granting you extended access to our Discord servers.

It is planned to be available at [account.fsi.rub.de](https://account.fsi.rub.de/), but due to internal scheduling reasons, it unfortunately isn't live yet.  
The backend is available [here](https://gitlab.ruhr-uni-bochum.de/fsi/idm/self-service-backend) (you may need to be logged in to view this link).

## How it works

- Single-page application powered by [React](https://react.dev/) and [TypeScript](https://www.typescriptlang.org/)
- Styling using [Tailwind CSS](https://tailwindcss.com/)
- [React Hook Form](https://react-hook-form.com/) for interative forms and input validation
- Keeping track of state using [zustand](https://github.com/pmndrs/zustand)
- Translation support using [FormatJS](https://formatjs.io/)
- API Response validation using the slim [Valibot](https://valibot.dev/) library
- [Vite](https://vitejs.dev/) as the build system, bundler, and tree-shaker 🌴
- Code formatting and linting using [Prettier](https://prettier.io/) and [ESLint](https://eslint.org/)
- Native [View Transitions](https://developer.mozilla.org/en-US/docs/Web/API/View_Transitions_API) thanks to [React Router](https://reactrouter.com/)

## Showcase

### Dark Mode Toggle

![Short video showcasing the dark mode toggle](readme_files/dark_mode.mp4)

### Language Toggle

![Short video demonstrating toggling the language between English and German](readme_files/language_toggle.mp4)

### View Transitions

![Short video showcasing animated navigation powered by the view transitions API](readme_files/view_transitions.mp4)

### Mobile Navigation

![Example video of using the mobile navigation hamburger/sidebar](readme_files/mobile_navigation.mp4)
