import { Navigate, useLocation } from "react-router-dom";
import { useLoginStore } from "../data/state/login";
import { useEffect } from "react";

interface Props {
	element: JSX.Element;
	fallback?: JSX.Element;
}

export default function AuthGuard({ element, fallback }: Props) {
	const [isLoggedIn, setRedirectTo] = useLoginStore(s => [s.isLoggedIn, s.setRedirectTo]);
	const location = useLocation();

	useEffect(() => {
		if (!isLoggedIn) {
			setRedirectTo(location.pathname);
		}
		// This should only run once.
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, []);

	if (isLoggedIn) {
		return element;
	}

	return fallback ?? <Navigate to="/login" />;
}
