import { ErrorBoundary } from "react-error-boundary";
import Logger from "../Logger";
import Icon from "../icons/WheelchairMove.svg?react";
import Button from "./widgets/Button";
import { useEffect, type ErrorInfo } from "react";
import { STYLES } from "../constants";
import { useRouteError } from "react-router-dom";

const TAG = "RootErrorBoundary";

export default function RootErrorBoundary({ children }: { children: React.ReactNode }) {
	return (
		<ErrorBoundary FallbackComponent={Fallback} onError={onError}>
			{children}
		</ErrorBoundary>
	);
}

export function ReactRouterErrorBoundary() {
	const error = useRouteError() as Error;

	useEffect(() => {
		onError(error);
	}, [error]);

	return <Fallback error={error} />;
}

const onError = (error: Error, info?: ErrorInfo) => {
	Logger.error(TAG, "Uncaught error in application", { error, info });
};

function Fallback({ error }: { error: Error }) {
	return (
		<div
			className={`min-h-screen flex flex-col items-center justify-center gap-8 pt-16 pb-8 mx-4 ${STYLES.TEXT_COLOR}`}>
			<Icon className="w-12 h-12 animate-spin fill-current" />
			<h2 className="font-bold text-2xl">Unexpected Error</h2>
			<p className="max-w-xl text-center">
				<a href="https://cdn.ai-rub.de/public/oopsie.mp4" className={`${STYLES.LINK_COLOR} underline`}>
					OOPSIE WOOPSIE!!
				</a>{" "}
				Uwu We made a fucky wucky!! A wittle fucko boingo! The code monkeys at our headquarters are working VEWY HAWD to
				fix this!
			</p>
			<div className="flex flex-row gap-8 flex-wrap justify-center">
				<Button onClick={() => location.reload()}>Reload Page</Button>
				<Button onClick={() => (location.pathname = "/")}>Go Home</Button>
			</div>
			<ErrorDetails error={error} />
			<img className="w-full max-w-lg" src="https://cdn.ai-rub.de/public/angrybird.jpg" />
		</div>
	);
}

function ErrorDetails({ error }: { error: Error }) {
	const errorMessage = error.message || "Unknown Error";
	return (
		<div className="grid place-items-center">
			<div className="max-w-full overflow-x-auto">
				<details
					className={`w-fit text-sm mt-4 bg-slate-100 dark:bg-slate-900 border ${STYLES.BORDER_COLOR} rounded-md`}>
					<summary className="p-4 cursor-pointer">{errorMessage}</summary>
					<pre className={`p-4 border-t ${STYLES.BORDER_COLOR}`}>{error.stack}</pre>
				</details>
			</div>
		</div>
	);
}
