import type { DefaultValues, FieldValues } from "react-hook-form";
import { FormProvider, useForm } from "react-hook-form";
import useEvents from "../../data/events/useEvents";
import { EventTypes } from "../../data/events/eventTypes";

interface Props<FormData> {
	onSubmit: (data: FormData) => void;
	formId?: string;
	defaultValues: FormData;
	className?: string;
	children: React.ReactNode;
}

export default function Form<FormData extends FieldValues>(props: Props<FormData>) {
	const form = useForm<FormData>({
		defaultValues: props.defaultValues as DefaultValues<FormData>,
	});

	const submitter = (e?: React.FormEvent) => void form.handleSubmit(props.onSubmit)(e);

	useEvents(data => {
		switch (data.type) {
			case EventTypes.FORM_SUBMIT:
				if (props.formId === data.formId) {
					submitter();
				}
				break;
			case EventTypes.FORM_RESET:
				if (props.formId === data.formId) {
					form.reset();
				}
				break;
			case EventTypes.FORM_SET_VALUE:
				if (props.formId === data.formId) {
					// eslint-disable-next-line @typescript-eslint/no-unsafe-argument
					form.setValue(data.key as any, data.value as any);
				}
				break;
		}
	});

	return (
		<FormProvider {...form}>
			<form className={props.className} onSubmit={submitter}>
				{props.children}
			</form>
		</FormProvider>
	);
}
