import { useFormContext } from "react-hook-form";
import { getFormItemErrorMessage } from "../../utils/utils";
import { STYLES } from "../../constants";

export type FormInputType = React.HTMLInputTypeAttribute | "textarea";

interface Props {
	name: string;
	type?: FormInputType;
	value?: string;
	required?: boolean;
	placeholder?: string;
	className?: string;
	children?: React.ReactNode;
}

export default function FormInput({ name, type, value, required, placeholder, className, children }: Props) {
	const { register, formState } = useFormContext<Record<string, string>>();
	const errorMessage = getFormItemErrorMessage(formState, name);

	const registration = register(name, {
		required: required ? "This value is required" : undefined,
		valueAsNumber: type === "number",
		setValueAs: (v: string | null | undefined) => v?.trim(),
	});

	const classes =
		"block w-full rounded overflow-hidden transition-colors " +
		"bg-white hover:bg-gray-100 dark:bg-gray-900 dark:hover:bg-slate-800 border border-slate-300 dark:border-slate-700";
	const inputClasses = "block w-full px-3 py-2 bg-transparent";

	const formElement =
		type === "textarea" ? (
			<textarea defaultValue={value} placeholder={placeholder} className={inputClasses} {...registration} />
		) : (
			<input
				type={type ?? "text"}
				defaultValue={value}
				placeholder={placeholder}
				className={inputClasses}
				{...registration}
			/>
		);

	return (
		<div className={className}>
			<div className={classes}>
				<div className="flex flex-row items-center">
					{formElement}
					{children}
				</div>
			</div>
			{errorMessage && <div className={`${STYLES.ERROR_COLOR} text-sm px-2`}>{errorMessage}</div>}
		</div>
	);
}
