import { Controller } from "react-hook-form";
import Select from "react-select";
import { getFormItemErrorMessage } from "../../utils/utils";
import { STYLES } from "../../constants";

export interface FormSelectOption {
	label: string;
	value: unknown;
	[k: string]: any;
}

interface Props {
	name: string;
	options: FormSelectOption[];
	value?: FormSelectOption[];
	required?: boolean;
	multiple?: boolean;
	disabled?: boolean;
}

const FormSelect = ({ name, options, multiple, required, value, disabled }: Props): JSX.Element => {
	const classes =
		"block w-full rounded border " +
		"bg-white hover:bg-gray-100 dark:bg-gray-900 dark:hover:bg-slate-800 border-slate-300 dark:border-slate-700";

	return (
		<Controller
			name={name}
			rules={{
				required,
			}}
			render={({ field, formState }) => {
				const errorMessage = getFormItemErrorMessage(formState, name);
				return (
					<div>
						<Select
							className={classes}
							options={options}
							isMulti={multiple}
							isClearable={false}
							isSearchable={false}
							isDisabled={disabled}
							defaultValue={value}
							unstyled
							classNames={{
								valueContainer: () => "mx-2.5",
								indicatorsContainer: () => "mx-2",
								menuList: () =>
									"mt-2 mb-4 py-2 bg-white dark:bg-gray-900 border border-slate-300 dark:border-slate-700 rounded",
								option: () => "p-2.5 hover:bg-gray-100 dark:hover:bg-slate-800 !cursor-pointer",
							}}
							{...field}
						/>
						{errorMessage && <div className={`${STYLES.ERROR_COLOR} text-sm px-2`}>{errorMessage}</div>}
					</div>
				);
			}}
		/>
	);
};

export default FormSelect;
