import { lazy } from "react";
import { Route, RouterProvider, createBrowserRouter, createRoutesFromElements } from "react-router-dom";
import { ReactRouterErrorBoundary } from "../RootErrorBoundary";
import App from "./App";
import LoginPage from "../pages/LoginPage";
import LogoutPage from "../pages/LogoutPage";
import NotFoundPage from "../pages/NotFoundPage";
import IndexPage from "../pages/IndexPage";
import OAuthCallbackPage from "../pages/OAuthCallbackPage";
import AuthGuard from "../AuthGuard";

const LazyAccountPage = lazy(() => import("../pages/AccountPage"));
const LazyDiscordLinkPage = lazy(() => import("../pages/DiscordLinkPage"));
const LazyContactPage = lazy(() => import("../pages/ContactPage"));
const LazyWidgetsPage = lazy(() => import("../pages/WidgetsPage"));

const router = createBrowserRouter(
	createRoutesFromElements(
		<Route element={<App />} errorElement={<ReactRouterErrorBoundary />}>
			<Route index element={<IndexPage />} />
			<Route path="/login" element={<LoginPage />} />
			<Route path="/logout" element={<LogoutPage />} />
			<Route path="/account" element={<AuthGuard element={<LazyAccountPage />} />} />
			<Route path="/discord" element={<AuthGuard element={<LazyDiscordLinkPage />} />} />
			<Route path="/contact" element={<LazyContactPage />} />
			<Route path="/auth/:type/callback" element={<OAuthCallbackPage />} />
			<Route path="/debug-widgets" element={<LazyWidgetsPage />} />
			<Route path="/*" element={<NotFoundPage />} />
		</Route>
	)
);

export default function AppRouter() {
	return <RouterProvider router={router} />;
}
