import { Link } from "react-router-dom";
import { STYLES } from "../../constants";
import type { WithClassName } from "../../utils/types";
import classNames from "classnames";
import NavigationHamburger from "./NavigationHamburger";
import LanguageSelect from "../widgets/LanguageSelect";
import ThemeToggle from "../widgets/ThemeToggle";

export default function Header() {
	return (
		<div className="max-lg:fixed inset-x-0 top-0 bg-body-light dark:bg-body-dark lg:contents">
			<HeaderLogo className={`max-lg:hidden border-b ${STYLES.BORDER_COLOR}`} />
			<header className={`flex flex-row items-center border-b ${STYLES.BORDER_COLOR} pr-4 sm:pr-8`}>
				<HeaderLogo className="max-sm:hidden lg:hidden ml-5" />
				<Link to="/" className="my-6 mx-4 sm:m-8" unstable_viewTransition>
					<h1 className="text-2xl font-bold">FSI Self-Service</h1>
				</Link>
				<div className="max-lg:hidden grow flex flex-row items-center justify-end gap-8">
					<LanguageSelect />
					<ThemeToggle />
				</div>
				<div className="lg:hidden grow flex justify-end">
					<NavigationHamburger />
				</div>
			</header>
		</div>
	);
}

export function HeaderLogo({ className }: WithClassName) {
	return (
		<div className={classNames(`grid place-items-center`, className)}>
			<Link to="/" unstable_viewTransition>
				<img src="/logo128.png" className="w-14 h-14 object-contain rounded" />
			</Link>
		</div>
	);
}
