import { STYLES } from "../../constants";
import Navigation from "./Navigation";
import { useNavigationStore } from "../../data/state/navigation";
import { HeaderLogo } from "./Header";
import HR from "../widgets/HR";
import LanguageSelect from "../widgets/LanguageSelect";
import classNames from "classnames";
import ThemeToggle from "../widgets/ThemeToggle";
import { Link } from "react-router-dom";

export default function MobileNavigation() {
	const [isVisible, setVisible] = useNavigationStore(s => [s.isVisible, s.setVisible]);

	const sidebarClasses =
		// Layout
		"lg:hidden fixed inset-y-0 right-0 w-64 overflow-y-auto " +
		// Visual
		`bg-body-light dark:bg-body-dark shadow-md ` +
		// Animation
		"transition-transform will-change-transform " +
		classNames({
			"translate-x-full": !isVisible,
			"translate-x-0": isVisible,
		});

	const backdropClasses = classNames("lg:hidden fixed inset-0 bg-black transition-opacity", {
		"opacity-0 pointer-events-none": !isVisible,
		"opacity-50": isVisible,
	});

	return (
		<>
			<div className={backdropClasses} onClick={() => setVisible(false)} />
			<div className={sidebarClasses}>
				<HeaderLogo className="m-4" />
				<Link to="/" unstable_viewTransition>
					<div className="font-bold text-xl text-center">FSI Self-Service</div>
					<div className={`${STYLES.MUTED_COLOR} text-center`}>at your service</div>
				</Link>
				<HR className="my-4" />
				<div className="flex items-center justify-center gap-8">
					<LanguageSelect />
					<ThemeToggle />
				</div>
				<HR className="my-4" />
				<Navigation />
			</div>
		</>
	);
}
