import classNames from "classnames";
import { NavLink } from "react-router-dom";
import type { WithClassName } from "../../utils/types";
import ArrowUpRightFromSquare from "../../icons/ArrowUpRightFromSquare.svg?react";
import useIntlMessages from "../i18n/useIntlMessages";
import { SERVICES_LIST_URL } from "../../constants";
import { useLoginStore } from "../../data/state/login";

export default function Navigation({ className }: WithClassName) {
	const isLoggedIn = useLoginStore(s => s.isLoggedIn);
	const intl = useIntlMessages();

	return (
		<nav className={classNames(`leading-none`, className)}>
			<ul>
				<NavigationLink name={intl("navigation.account")} to="/account" />
				<NavigationLink name={intl("navigation.discord-link")} to="/discord" />
				<NavigationLink name={intl("navigation.contact")} to="/contact" />
				<NavigationLink name={intl("navigation.services")} to={SERVICES_LIST_URL} />
				<NavigationLink name="WIDGETS" to="/debug-widgets" />
				{isLoggedIn && <NavigationLink name={intl("logout")} to="/logout" />}
			</ul>
		</nav>
	);
}

interface NavigationLinkProps {
	name: string;
	to: string;
}

function NavigationLink({ name, to }: NavigationLinkProps) {
	const isExternal = to.startsWith("https://");

	const defaultColor = "text-slate-600 dark:text-slate-300 hover:text-black dark:hover:text-white";

	const linkComponent = isExternal ? (
		<a href={to} target="_blank" rel="noreferrer" className={`flex flex-row items-center gap-2 p-5 ${defaultColor}`}>
			<span>{name}</span>
			<ArrowUpRightFromSquare className="w-3 h-3 fill-current" />
		</a>
	) : (
		<NavLink
			unstable_viewTransition
			to={to}
			className={({ isActive, isPending }) =>
				classNames("block p-5", {
					[defaultColor]: !isActive && !isPending,
					"bg-blue-100 dark:bg-slate-700 text-blue-900 dark:text-blue-200": isActive || isPending,
				})
			}>
			{name}
		</NavLink>
	);

	return <li>{linkComponent}</li>;
}
