import ApiActions from "../../data/ApiActions";
import { useUserStore } from "../../data/state/user";
import { usePreload } from "../../utils/usePreload";
import Message from "../i18n/Message";
import LoadingIndicator from "../widgets/LoadingIndicator";
import TextLink from "../widgets/TextLink";
import { H2 } from "../widgets/typography/Heading";
import P from "../widgets/typography/Paragraph";
import AccountPanel from "../widgets/account/AccountPanel";

export default function AccountPage() {
	usePreload("user-account", () => ApiActions.fetchSelf());
	const user = useUserStore(s => s.data);

	const accountPanel = user ? (
		<AccountPanel user={user} className="mt-8" />
	) : (
		<LoadingIndicator className="mt-16">
			<Message id="account.loading" />
		</LoadingIndicator>
	);

	return (
		<>
			<H2>
				<Message id="account.title" />
			</H2>
			<P>
				<Message
					id="account.description"
					vars={{
						link: children => <TextLink to="https://auth.fs-its.rub.de/realms/fsr-ffi/account/">{children}</TextLink>,
					}}
				/>
			</P>
			{accountPanel}
		</>
	);
}
