import ApiActions from "../../data/ApiActions";
import { useDiscordStore } from "../../data/state/discord";
import { usePreload } from "../../utils/usePreload";
import Message from "../i18n/Message";
import useIntlMessages from "../i18n/useIntlMessages";
import HR from "../widgets/HR";
import LoadingIndicator from "../widgets/LoadingIndicator";
import DiscordConnectionManagement from "../widgets/discord/DiscordConnectionManagement";
import type { DiscordServerListServerProps } from "../widgets/discord/DiscordServerList";
import DiscordServerList from "../widgets/discord/DiscordServerList";
import { H2 } from "../widgets/typography/Heading";
import P from "../widgets/typography/Paragraph";

export default function DiscordLinkPage() {
	usePreload("discord-connection", () => ApiActions.fetchDiscordConnection());

	const intl = useIntlMessages();
	const discord = useDiscordStore(s => s.data);
	const guilds = discord?.guilds.map(g => ({
		...g,
		iconHash: g.icon_hash,
		memberCount: g.member_count,
		inviteCode: g.invite_code,
		isMember: g.is_member,
	})) satisfies DiscordServerListServerProps[] | undefined;

	const connectionManagement = discord ? <DiscordConnectionManagement className="my-8" /> : null;

	const guildList = guilds ? (
		<>
			<HR />
			<DiscordServerList
				title={intl("discord.servers.joined.title")}
				emptyPlaceholder={intl("discord.servers.joined.placeholder")}
				guilds={guilds.filter(g => g.isMember)}
			/>
			<HR />
			<DiscordServerList
				title={intl("discord.servers.available.title")}
				emptyPlaceholder={intl("discord.servers.available.placeholder")}
				guilds={guilds.filter(g => !g.isMember)}
			/>
		</>
	) : (
		<LoadingIndicator className="mt-16">
			<Message id="discord.loading" />
		</LoadingIndicator>
	);

	return (
		<>
			<H2>
				<Message id="discord.title" />
			</H2>
			<P className="whitespace-pre-line">
				<Message id="discord.description" />
			</P>
			{connectionManagement}
			{guildList}
		</>
	);
}
