import { useNavigate } from "react-router-dom";
import { EventTypes } from "../../data/events/eventTypes";
import useEvents from "../../data/events/useEvents";
import { OAuthType, startOAuthFlow } from "../../utils/oauth";
import { H2 } from "../widgets/typography/Heading";
import P from "../widgets/typography/Paragraph";
import { useEffect, useState } from "react";
import { STYLES } from "../../constants";
import Message from "../i18n/Message";
import Button from "../widgets/Button";
import { useLoginStore } from "../../data/state/login";

export default function LoginPage() {
	const [errorMessage, setErrorMessage] = useState<string | null>(null);
	const [isLoggedIn, redirectTo, setRedirectTo] = useLoginStore(s => [s.isLoggedIn, s.redirectTo, s.setRedirectTo]);
	const navigate = useNavigate();

	const redirectAfterLogin = () => {
		setRedirectTo(null);
		navigate(redirectTo ?? "/", {
			replace: true,
			unstable_viewTransition: true,
		});
	};

	useEvents(data => {
		switch (data.type) {
			case EventTypes.RUB_EXCHANGE_CODE_FAIL:
			case EventTypes.POPUP_FAIL:
				setErrorMessage(data.error.message);
				break;
			case EventTypes.RUB_EXCHANGE_CODE_SUCCESS:
				redirectAfterLogin();
				break;
		}
	});

	useEffect(() => {
		if (isLoggedIn) {
			redirectAfterLogin();
		} else {
			startOAuthFlow(OAuthType.RUB);
		}
		// This should only run once.
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, []);

	const onRetryClick = () => {
		setErrorMessage(null);
		startOAuthFlow(OAuthType.RUB);
	};

	const content = errorMessage ? (
		<>
			<P className={`${STYLES.ERROR_COLOR}`}>
				<Message id="login.error" vars={{ errorMessage }} />
			</P>
			<Button onClick={onRetryClick}>
				<Message id="login.retry" />
			</Button>
		</>
	) : (
		<P>
			<Message id="login.description" />
		</P>
	);

	return (
		<>
			<H2>
				<Message id="login.title" />
			</H2>
			{content}
		</>
	);
}
