import { useEffect, useState } from "react";
import { H2 } from "../widgets/typography/Heading";
import P from "../widgets/typography/Paragraph";
import { useParams, useSearchParams } from "react-router-dom";
import uniqueId from "../../utils/uniqueId";

enum State {
	LOADING,
	SUCCESS,
	TIMEOUT,
}

export default function OAuthCallbackPage() {
	const [pageState, setPageState] = useState<State>(State.LOADING);

	const { type } = useParams();
	const [searchParams] = useSearchParams();
	const code = searchParams.get("code");
	const state = searchParams.get("state");
	const error = searchParams.get("error");
	const errorDescription = searchParams.get("error_description");

	useEffect(() => {
		const messageId = uniqueId("oacb");

		window.addEventListener("message", e => {
			if (
				e.origin !== location.origin ||
				typeof e.data !== "object" ||
				!("messageId" in e.data) ||
				e.data.messageId !== messageId ||
				!("type" in e.data) ||
				e.data.type !== `oauth-confirm:${type}`
			) {
				return;
			}
			setPageState(State.SUCCESS);
			window.close();
		});

		const timeout = setTimeout(() => {
			setPageState(State.TIMEOUT);
		}, 2000);

		window.parent.postMessage(
			{
				messageId,
				type: `oauth-callback:${type}`,
				code,
				state,
				error,
				errorDescription,
			},
			location.origin
		);

		return () => {
			clearTimeout(timeout);
		};
		// This should only run once.
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, []);

	if (pageState === State.LOADING) {
		return (
			<>
				<H2>Authorizing…</H2>
				<P>Please wait</P>
			</>
		);
	}

	if (pageState === State.SUCCESS) {
		return (
			<>
				<H2>Authorized</H2>
				<P>You may now close this window.</P>
			</>
		);
	}

	return (
		<>
			<H2>Authorization Error</H2>
			<P>Couldn&apos;t contact the parent window. Did you close the original tab?</P>
		</>
	);
}
