import classNames from "classnames";
import type { LinkProps } from "react-router-dom";
import { Link } from "react-router-dom";
import ArrowUpRightFromSquare from "../../icons/ArrowUpRightFromSquare.svg?react";
import { STYLES } from "../../constants";

/* eslint-disable no-mixed-spaces-and-tabs */
type TextLinkProps = Omit<LinkProps, "to"> &
	(
		| {
				to: string;
				children: React.ReactNode;
		  }
		| {
				children: string;
				to?: string | null;
		  }
	);
/* eslint-enable no-mixed-spaces-and-tabs */

export default function TextLink({ className, children, to, ...props }: TextLinkProps) {
	if (!to) {
		to = children as string;
	}
	const isExternal = to.startsWith("https://") || to.startsWith("mailto:");

	const classes = classNames("group underline transition-colors", STYLES.LINK_COLOR, className);

	if (isExternal) {
		return (
			<a
				href={to}
				target="_blank"
				rel="noreferrer"
				className={`inline-flex flex-row items-baseline gap-0.5 ${classes}`}>
				<span>{children}</span>
				<ArrowUpRightFromSquare className="w-3 h-3 fill-current" />
			</a>
		);
	}

	return (
		<Link className={classes} to={to} unstable_viewTransition {...props}>
			{children}
		</Link>
	);
}
