import classNames from "classnames";
import { COURSES, STYLES } from "../../../constants";
import ApiActions from "../../../data/ApiActions";
import type { ApiGetMeResponse } from "../../../data/schemas";
import type { WithClassName } from "../../../utils/types";
import Form from "../../forms/Form";
import FormInput from "../../forms/FormInput";
import FormSelect from "../../forms/FormSelect";
import Message from "../../i18n/Message";
import P from "../typography/Paragraph";
import EditableAccountField from "./EditableAccountField";

const courseOptions = COURSES.map(c => ({
	label: c,
	value: c,
}));

interface Props {
	user: ApiGetMeResponse;
}

export default function AccountPanel({ user, className }: WithClassName<Props>) {
	const groupList = user.groups.length ? (
		<ul className="flex flex-col gap-2">
			{user.groups.sort().map(g => (
				<li key={g}>{g}</li>
			))}
		</ul>
	) : (
		<em>
			<Message id="account.no-groups" />
		</em>
	);

	const classes = `grid grid-cols-[auto_1fr] gap-4 items-center leading-none border ${STYLES.BORDER_COLOR} p-4 rounded-lg`;

	return (
		<div className={classNames(classes, className)}>
			<strong>
				<Message id="account.name" />
			</strong>
			<EditableAccountField
				value={user.name}
				renderForm={formControls => (
					<Form
						formId="edit-name"
						defaultValues={{ name: user.name }}
						onSubmit={data =>
							ApiActions.updateSelf({
								name: data.name,
							})
						}>
						<P className="whitespace-pre-line">
							<Message id="account.edit.name.info" />
						</P>
						<FormInput name="name" required />
						{formControls}
					</Form>
				)}
			/>
			<Divider />

			<strong>
				<Message id="account.email" />
			</strong>
			<div>{user.email}</div>
			<Divider />

			<strong>
				<Message id="account.groups" />
			</strong>
			<div>{groupList}</div>
			<Divider />

			<strong>
				<Message id="account.course" />
			</strong>
			<EditableAccountField
				value={user.course}
				renderForm={formControls => (
					<Form
						formId="edit-course"
						defaultValues={{ course: courseOptions.find(o => o.value === user.course) }}
						onSubmit={data =>
							ApiActions.updateSelf({
								course: data.course?.value,
							})
						}>
						<P className="whitespace-pre-line">
							<Message id="account.edit.course.info" />
						</P>
						<FormSelect name="course" options={courseOptions} required />
						{formControls}
					</Form>
				)}
			/>
		</div>
	);
}

function Divider() {
	return <div className={`col-span-full justify-self-stretch border-t ${STYLES.BORDER_COLOR} -mx-4`} />;
}
