import { useState } from "react";
import useEvents from "../../../data/events/useEvents";
import { EventTypes } from "../../../data/events/eventTypes";
import Message from "../../i18n/Message";
import { STYLES } from "../../../constants";
import Button from "../Button";
import EditIcon from "../../../icons/PenToSquare.svg?react";

interface Props {
	value: string;
	renderForm: (formControls: React.ReactNode) => React.ReactNode;
}

export default function EditableAccountField({ value, renderForm }: Props) {
	const [isExpanded, setExpanded] = useState<boolean>(false);
	const [isLoading, setLoading] = useState<boolean>(false);
	const [errorMessage, setErrorMessage] = useState<string | null>(null);

	const setExpansion = (expanded: boolean | null) => {
		setExpanded(e => expanded ?? !e);
		setErrorMessage(null);
	};

	useEvents(data => {
		switch (data.type) {
			case EventTypes.UPDATE_SELF:
				setErrorMessage(null);
				setLoading(true);
				break;
			case EventTypes.UPDATE_SELF_SUCCESS:
				setErrorMessage(null);
				setExpanded(false);
				setLoading(false);
				break;
			case EventTypes.UPDATE_SELF_FAIL:
				setErrorMessage(data.error.message);
				setLoading(false);
				break;
		}
	});

	const renderedErrorMessage = errorMessage && (
		<div className={`${STYLES.ERROR_COLOR}`}>
			<Message id="account.edit.error" vars={{ errorMessage }} />
		</div>
	);

	const editFieldForm = isExpanded ? (
		<div className="col-span-full sm:col-start-2 flex flex-col gap-4">
			{renderForm(
				<div className="mt-8 flex flex-row gap-4 items-center justify-center">
					<Button buttonStyle="info" small outlined disabled={isLoading} onClick={() => setExpansion(false)}>
						<Message id="account.edit.cancel" />
					</Button>
					<Button buttonStyle="success" small type="submit" loading={isLoading}>
						<Message id="account.edit.confirm" />
					</Button>
				</div>
			)}
			{renderedErrorMessage}
		</div>
	) : null;

	return (
		<>
			<div className="flex flex-col gap-4">
				<button className="inline-flex flex-row items-center gap-2 w-fit" onClick={() => setExpansion(null)}>
					<div>{value}</div>
					<EditIcon className="w-3.5 h-3.5 fill-current" />
				</button>
			</div>
			{editFieldForm}
		</>
	);
}
