import classNames from "classnames";

interface HeadingProps {
	level: 1 | 2 | 3 | 4 | 5 | 6;
	baseClasses: string;
}

function Heading({ level, baseClasses, className, ...props }: HeadingProps & JSX.IntrinsicElements["h2"]) {
	const Type = `h${level}` as const;
	const classes = classNames(baseClasses, className);
	return <Type className={classes} {...props} />;
}

export function H2(props: JSX.IntrinsicElements["h2"]) {
	return <Heading level={2} baseClasses="font-bold text-2xl mt-8 mb-4 first:mt-3" {...props} />;
}

export function H3(props: JSX.IntrinsicElements["h1"]) {
	return <Heading level={3} baseClasses="font-bold text-xl mt-8 mb-4 first:mt-2" {...props} />;
}
