import type { IntlMessageMap } from "../../components/i18n/AppIntlProvider";
import type { ApiErrorResponse, ApiResponse } from "../ApiRequests";
import type {
	ApiDeleteDiscordResponse,
	ApiGetDiscordResponse,
	ApiGetMeResponse,
	ApiPatchMeResponse,
	ApiPostAuthDiscordTokenResponse,
} from "../schemas";

export const EventTypes = {
	FETCH_SELF: "FETCH_SELF",
	FETCH_SELF_SUCCESS: "FETCH_SELF_SUCCESS",
	FETCH_SELF_FAIL: "FETCH_SELF_FAIL",
	UPDATE_SELF: "UPDATE_SELF",
	UPDATE_SELF_SUCCESS: "UPDATE_SELF_SUCCESS",
	UPDATE_SELF_FAIL: "UPDATE_SELF_FAIL",

	FETCH_DISCORD_CONNECTION: "FETCH_DISCORD_CONNECTION",
	FETCH_DISCORD_CONNECTION_SUCCESS: "FETCH_DISCORD_CONNECTION_SUCCESS",
	FETCH_DISCORD_CONNECTION_FAIL: "FETCH_DISCORD_CONNECTION_FAIL",
	REMOVE_DISCORD_CONNECTION: "REMOVE_DISCORD_CONNECTION",
	REMOVE_DISCORD_CONNECTION_SUCCESS: "REMOVE_DISCORD_CONNECTION_SUCCESS",
	REMOVE_DISCORD_CONNECTION_FAIL: "REMOVE_DISCORD_CONNECTION_FAIL",
	DISCORD_EXCHANGE_CODE: "DISCORD_EXCHANGE_CODE",
	DISCORD_EXCHANGE_CODE_SUCCESS: "DISCORD_EXCHANGE_CODE_SUCCESS",
	DISCORD_EXCHANGE_CODE_FAIL: "DISCORD_EXCHANGE_CODE_FAIL",

	RUB_EXCHANGE_CODE: "RUB_EXCHANGE_CODE",
	RUB_EXCHANGE_CODE_SUCCESS: "RUB_EXCHANGE_CODE_SUCCESS",
	RUB_EXCHANGE_CODE_FAIL: "RUB_EXCHANGE_CODE_FAIL",
	LOGOUT: "LOGOUT",
	LOGOUT_SUCCESS: "LOGOUT_SUCCESS",
	LOGOUT_FAIL: "LOGOUT_FAIL",
	LOGOUT_COMPLETE: "LOGOUT_COMPLETE",

	API_CALL_FAIL: "API_CALL_FAIL",
	POPUP_FAIL: "POPUP_FAIL",

	LANGUAGE_LOAD_SUCCESS: "LANGUAGE_LOAD_SUCCESS",
	LANGUAGE_LOAD_FAIL: "LANGUAGE_LOAD_FAIL",

	FORM_SUBMIT: "FORM_SUBMIT",
	FORM_RESET: "FORM_RESET",
	FORM_SET_VALUE: "FORM_SET_VALUE",
} as const;

export interface EventData {
	[EventTypes.FETCH_SELF_SUCCESS]: { user: ApiGetMeResponse };
	[EventTypes.FETCH_SELF_FAIL]: { error: Error };
	[EventTypes.UPDATE_SELF_SUCCESS]: { user: ApiPatchMeResponse };
	[EventTypes.UPDATE_SELF_FAIL]: { error: Error };

	[EventTypes.FETCH_DISCORD_CONNECTION_SUCCESS]: { discord: ApiGetDiscordResponse };
	[EventTypes.FETCH_DISCORD_CONNECTION_FAIL]: { error: Error };
	[EventTypes.REMOVE_DISCORD_CONNECTION_SUCCESS]: { discord: ApiDeleteDiscordResponse };
	[EventTypes.REMOVE_DISCORD_CONNECTION_FAIL]: { error: Error };
	[EventTypes.DISCORD_EXCHANGE_CODE_SUCCESS]: { discord: ApiPostAuthDiscordTokenResponse };
	[EventTypes.DISCORD_EXCHANGE_CODE_FAIL]: { error: Error };

	[EventTypes.RUB_EXCHANGE_CODE_FAIL]: { error: Error };
	[EventTypes.LOGOUT_FAIL]: { error: Error };

	[EventTypes.API_CALL_FAIL]: { error: Error; response: ApiResponse<ApiErrorResponse> };
	[EventTypes.POPUP_FAIL]: { error: Error };

	[EventTypes.LANGUAGE_LOAD_SUCCESS]: { language: IntlMessageMap };
	[EventTypes.LANGUAGE_LOAD_FAIL]: { error: Error };

	[EventTypes.FORM_SUBMIT]: { formId: string };
	[EventTypes.FORM_RESET]: { formId: string };
	[EventTypes.FORM_SET_VALUE]: { formId: string; key: string; value: unknown };
}
