import { array, boolean, email, integer, nullable, number, object, string } from "valibot";
import type { Output } from "valibot";

// https://docs.fsi.rub.de/doc/self-service-api-spec-6myB1GdHmK

// --- GET /me ---

export const ApiGetMeResponseSchema = object({
	name: string(),
	email: string([email()]),
	course: string(),
	groups: array(string()),
});
export type ApiGetMeResponse = Output<typeof ApiGetMeResponseSchema>;

// --- PATCH /me ---

export interface ApiPatchMeRequest {
	name?: string;
	course?: string;
}

export const ApiPatchMeResponseSchema = ApiGetMeResponseSchema;
export type ApiPatchMeResponse = ApiGetMeResponse;

// --- GET /discord ---

export const ApiGetDiscordResponseSchema = object({
	user: nullable(
		object({
			id: string(),
			username: string(),
		})
	),
	guilds: array(
		object({
			id: string(),
			name: string(),
			icon_hash: nullable(string()),
			member_count: number([integer()]),
			invite_code: string(),
			is_member: boolean(),
			roles: array(
				object({
					id: string(),
					name: string(),
					color: number([integer()]),
				})
			),
		})
	),
});
export type ApiGetDiscordResponse = Output<typeof ApiGetDiscordResponseSchema>;

// --- DELETE /discord ---

export const ApiDeleteDiscordResponseSchema = ApiGetDiscordResponseSchema;
export type ApiDeleteDiscordResponse = ApiGetDiscordResponse;

// --- POST /auth/rub/token ---

export interface ApiPostAuthRubTokenRequest {
	code: string;
}

export const ApiPostAuthRubResponseSchema = object({
	authorization: string(),
});
export type ApiPostAuthRubResponse = Output<typeof ApiPostAuthRubResponseSchema>;

// --- POST /auth/discord/token ---

export interface ApiPostAuthDiscordTokenRequest {
	code: string;
}

export const ApiPostAuthDiscordTokenResponseSchema = ApiGetDiscordResponseSchema;
export type ApiPostAuthDiscordTokenResponse = ApiGetDiscordResponse;
