import type { FormState } from "react-hook-form";

export const getRandomArrayItem = <T>(arr: T[]): T => arr[Math.floor(Math.random() * arr.length)]!;

export const getFormItemErrorMessage = (state: FormState<Record<string, string>>, fieldName: string): string | null => {
	const validationError = state.errors[fieldName];
	if (!validationError) {
		return null;
	}
	return validationError.message ?? validationError.type;
};

export const pluralize = (count: number, singular: string, plural?: string): string =>
	plural && count !== 1 ? plural : singular + (count === 1 ? "" : "s");

export const colorToHex = (color: number): string => `#${color.toString(16).padStart(6, "0")}`;
