import { defineConfig } from "vite"
import react from "@vitejs/plugin-react"
import svgr from "vite-plugin-svgr"
import { visualizer } from "rollup-plugin-visualizer";
import injectPreload from "unplugin-inject-preload/vite";

// https://vitejs.dev/config/
export default defineConfig({
    plugins: [svgr({
		svgrOptions: {
			typescript: true,
		},
		esbuildOptions: {
			loader: 'tsx',
		},
	}), react(), visualizer({
        filename: "./dist/stats.html",
        gzipSize: true,
        brotliSize: true,
    }), injectPreload({
		injectTo: "head",
		files: [{
			outputMatch: /de-[a-z0-9]+\.js$/,
			attributes: {
				rel: "modulepreload",
				type: undefined,
				as: undefined,
			},
		}],
	})],
    build: {
        sourcemap: true,
    },
    preview: {
        port: 5173,
    },
	define: {
		__APP_VERSION__: JSON.stringify(process.env.npm_package_version),
	},
})
